package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.LzydNoticeMapper;
import com.ruoyi.system.domain.LzydNotice;
import com.ruoyi.system.service.ILzydNoticeService;

/**
 * 公告模块Service业务层处理
 * 
 * @author ruoyi
 * @date 2021-04-07
 */
@Service
public class LzydNoticeServiceImpl implements ILzydNoticeService 
{
    @Autowired
    private LzydNoticeMapper lzydNoticeMapper;

    /**
     * 查询公告模块
     * 
     * @param id 公告模块ID
     * @return 公告模块
     */
    @Override
    public LzydNotice selectLzydNoticeById(Long id)
    {
        return lzydNoticeMapper.selectLzydNoticeById(id);
    }

    /**
     * 查询公告模块列表
     * 
     * @param lzydNotice 公告模块
     * @return 公告模块
     */
    @Override
    public List<LzydNotice> selectLzydNoticeList(LzydNotice lzydNotice)
    {
        return lzydNoticeMapper.selectLzydNoticeList(lzydNotice);
    }

    /**
     * 新增公告模块
     * 
     * @param lzydNotice 公告模块
     * @return 结果
     */
    @Override
    public int insertLzydNotice(LzydNotice lzydNotice)
    {
        return lzydNoticeMapper.insertLzydNotice(lzydNotice);
    }

    /**
     * 修改公告模块
     * 
     * @param lzydNotice 公告模块
     * @return 结果
     */
    @Override
    public int updateLzydNotice(LzydNotice lzydNotice)
    {
        return lzydNoticeMapper.updateLzydNotice(lzydNotice);
    }

    /**
     * 批量删除公告模块
     * 
     * @param ids 需要删除的公告模块ID
     * @return 结果
     */
    @Override
    public int deleteLzydNoticeByIds(Long[] ids)
    {
        return lzydNoticeMapper.deleteLzydNoticeByIds(ids);
    }

    /**
     * 删除公告模块信息
     * 
     * @param id 公告模块ID
     * @return 结果
     */
    @Override
    public int deleteLzydNoticeById(Long id)
    {
        return lzydNoticeMapper.deleteLzydNoticeById(id);
    }
}
